from django.template.loader import get_template

from juntagrico.mailer import EmailSender, base_dict
from juntagrico.config import Config

from juntagrico_assignment_request.mailer import get_approver_emails
from juntagrico_assignment_request.config import AssignmentRequestConfig


def content_render(assignment_request, template, **kwargs):
    kwargs.update({'assignment_request': assignment_request})
    d = base_dict(kwargs)
    plaintext = get_template(AssignmentRequestConfig.emails(template))
    return plaintext.render(d)


def request_created(assignment_request):
    EmailSender.get_sender(Config.organisation_name() + ' - Neue ' + Config.vocabulary('assignment') + '-Anfrage',
                           content_render(assignment_request, 'new_assignment_request_mail'))\
        .send_to(get_approver_emails(assignment_request))


def request_handled_by_other_approver(assignment_request, new_approver):
    """
    notify original approver, if another approver handled the request
    """
    if assignment_request.approver and assignment_request.approver != new_approver:
        EmailSender.get_sender(Config.organisation_name() + ' - ' + Config.vocabulary('assignment') + '-Anfrage erledigt',
                               content_render(assignment_request, 'notify_original_approver_mail',
                                              new_approver=new_approver))\
            .send_to(get_approver_emails(assignment_request))


def request_changed(assignment_request):
    EmailSender.get_sender(Config.organisation_name() + ' - ' + Config.vocabulary('assignment') + '-Anfrage bearbeitet',
                           content_render(assignment_request, 'edited_assignment_request_mail'))\
        .send_to(get_approver_emails(assignment_request))



from django.contrib import admin

from juntagrico_assignment_request.admins.assignment_request_admin import AssignmentRequestAdmin
from juntagrico_assignment_request.entity.assignment_request import AssignmentRequest

admin.site.register(AssignmentRequest, AssignmentRequestAdmin)



# Generated by Django 2.2.4 on 2019-10-20 22:07

import datetime
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('juntagrico', '0018_auto_20191019_2031'),
    ]

    operations = [
        migrations.CreateModel(
            name='AssignmentRequest',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('amount', models.PositiveIntegerField(default=1, validators=[django.core.validators.MinValueValidator(1)], verbose_name='Wert')),
                ('job_time', models.DateTimeField(default=datetime.datetime.now, verbose_name='Geleistet am')),
                ('request_date', models.DateField(blank=True, default=datetime.date.today, null=True, verbose_name='Beantragt am')),
                ('description', models.TextField(default='', max_length=1000, verbose_name='Beschreibung')),
                ('duration', models.PositiveIntegerField(default=4, verbose_name='Dauer in Stunden')),
                ('location', models.CharField(blank=True, default='', max_length=100, verbose_name='Ort')),
                ('status', models.CharField(choices=[('RE', 'Beantragt'), ('NO', 'Abgelehnt'), ('CO', 'Bestätigt')], default='RE', max_length=2)),
                ('response', models.TextField(blank=True, null=True, verbose_name='Antwort')),
                ('activityarea', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='juntagrico.ActivityArea')),
                ('assignment', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='juntagrico.Assignment')),
                ('member', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='juntagrico.Member')),
                ('approver', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='Referenz', to='juntagrico.Member')),
                ('response_date', models.DateField(blank=True, null=True, verbose_name='Beantwortet am')),
            ],
            options={
                'verbose_name': 'Arbeitseinsatz Anfrage',
                'verbose_name_plural': 'Arbeitseinsatz Anfragen',
                'permissions': (('can_confirm_assignments', 'Kann selbständige Arbeitseinsätze bestätigen'), ('notified_on_unapproved_assignments', 'Wird über nicht abgesprochene Arbeitseinsätze informiert')),
            },
        ),
    ]



from juntagrico.admins.job_admin import JobAdmin
from juntagrico.admins.job_type_admin import JobTypeAdmin
from juntagrico.util import addons

import juntagrico_assignment_request

addons.config.register_user_menu('assignment_request/menu/assignment_request_user_menu.html')
addons.config.register_admin_menu('assignment_request/menu/assignment_request_admin_menu.html')
addons.config.register_version(juntagrico_assignment_request.name, juntagrico_assignment_request.version)


#############################################
# Hide automatically generated jobs and types
# in admin by monkey patching

def get_job_type_queryset(self, request):
    return original_get_job_type_queryset(self, request).exclude(
        recuringjob__assignment__assignmentrequest__isnull=False)


def get_job_queryset(self, request):
    return original_get_job_queryset(self, request).exclude(
        assignment__assignmentrequest__isnull=False)


original_get_job_type_queryset = JobTypeAdmin.get_queryset
JobTypeAdmin.get_queryset = get_job_type_queryset
original_get_job_queryset = JobAdmin.get_queryset
JobAdmin.get_queryset = get_job_queryset



# Generated by Django 3.2.2 on 2021-12-07 10:01

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('juntagrico_assignment_request', '0003_change_assignment_helptext'),
    ]

    operations = [
        migrations.AlterField(
            model_name='assignmentrequest',
            name='amount',
            field=models.PositiveIntegerField(default=1, validators=[django.core.validators.MinValueValidator(1)], verbose_name='Wert'),
        ),
        migrations.AlterField(
            model_name='assignmentrequest',
            name='duration',
            field=models.DecimalField(decimal_places=2, default=4.0, max_digits=4, verbose_name='Dauer in Stunden'),
        ),
    ]
